@@ -3,6 +3,8 @@ use crate::client_certificate_type::ClientCertificateType;
 use crate::crypto::crypto_ccm::{CryptoCcm, CryptoCcmTagLen};
 use crate::prf::*;
 
+use anyhow::Result;
+
 #[derive(Clone)]
 pub struct CipherSuiteAes128Ccm {
     ccm: Option<CryptoCcm>,
@@ -64,7 +66,7 @@ impl CipherSuite for CipherSuiteAes128Ccm {
         client_random: &[u8],
         server_random: &[u8],
         is_client: bool,
-    ) -> Result<(), Error> {
+    ) -> Result<()> {
         let keys = prf_encryption_keys(
             master_secret,
             client_random,
@@ -96,23 +98,25 @@ impl CipherSuite for CipherSuiteAes128Ccm {
         Ok(())
     }
 
-    fn encrypt(&self, pkt_rlh: &RecordLayerHeader, raw: &[u8]) -> Result<Vec<u8>, Error> {
+    fn encrypt(&self, pkt_rlh: &RecordLayerHeader, raw: &[u8]) -> Result<Vec<u8>> {
         if let Some(ccm) = &self.ccm {
             ccm.encrypt(pkt_rlh, raw)
         } else {
             Err(Error::ErrOthers(
                 "CipherSuite has not been initialized, unable to encrypt".to_owned(),
-            ))
+            )
+            .into())
         }
     }
 
-    fn decrypt(&self, input: &[u8]) -> Result<Vec<u8>, Error> {
+    fn decrypt(&self, input: &[u8]) -> Result<Vec<u8>> {
         if let Some(ccm) = &self.ccm {
             ccm.decrypt(input)
         } else {
             Err(Error::ErrOthers(
                 "CipherSuite has not been initialized, unable to decrypt".to_owned(),
-            ))
+            )
+            .into())
         }
     }
 }
