@@ -104,7 +104,7 @@ impl CryptoCcm {
         }
     }
 
-    pub fn encrypt(&self, pkt_rlh: &RecordLayerHeader, raw: &[u8]) -> Result<Vec<u8>, Error> {
+    pub fn encrypt(&self, pkt_rlh: &RecordLayerHeader, raw: &[u8]) -> Result<Vec<u8>> {
         let payload = &raw[RECORD_LAYER_HEADER_SIZE..];
         let raw = &raw[..RECORD_LAYER_HEADER_SIZE];
 
@@ -120,10 +120,12 @@ impl CryptoCcm {
 
         match &self.local_ccm {
             CryptoCcmType::CryptoCcm(ccm) => {
-                ccm.encrypt_in_place(nonce, &additional_data, &mut buffer)?;
+                ccm.encrypt_in_place(nonce, &additional_data, &mut buffer)
+                    .map_err(|e| Error::ErrOthers(e.to_string()))?;
             }
             CryptoCcmType::CryptoCcm8(ccm8) => {
-                ccm8.encrypt_in_place(nonce, &additional_data, &mut buffer)?;
+                ccm8.encrypt_in_place(nonce, &additional_data, &mut buffer)
+                    .map_err(|e| Error::ErrOthers(e.to_string()))?;
             }
         }
 
@@ -141,7 +143,7 @@ impl CryptoCcm {
         Ok(r)
     }
 
-    pub fn decrypt(&self, r: &[u8]) -> Result<Vec<u8>, Error> {
+    pub fn decrypt(&self, r: &[u8]) -> Result<Vec<u8>> {
         let mut reader = Cursor::new(r);
         let h = RecordLayerHeader::unmarshal(&mut reader)?;
         if h.content_type == ContentType::ChangeCipherSpec {
@@ -150,7 +152,7 @@ impl CryptoCcm {
         }
 
         if r.len() <= (RECORD_LAYER_HEADER_SIZE + 8) {
-            return Err(Error::ErrNotEnoughRoomForNonce);
+            return Err(Error::ErrNotEnoughRoomForNonce.into());
         }
 
         let mut nonce = vec![];
@@ -167,12 +169,14 @@ impl CryptoCcm {
             CryptoCcmType::CryptoCcm(ccm) => {
                 let additional_data =
                     generate_aead_additional_data(&h, out.len() - CRYPTO_CCM_TAG_LENGTH);
-                ccm.decrypt_in_place(nonce, &additional_data, &mut buffer)?;
+                ccm.decrypt_in_place(nonce, &additional_data, &mut buffer)
+                    .map_err(|e| Error::ErrOthers(e.to_string()))?;
             }
             CryptoCcmType::CryptoCcm8(ccm8) => {
                 let additional_data =
                     generate_aead_additional_data(&h, out.len() - CRYPTO_CCM_8_TAG_LENGTH);
-                ccm8.decrypt_in_place(nonce, &additional_data, &mut buffer)?;
+                ccm8.decrypt_in_place(nonce, &additional_data, &mut buffer)
+                    .map_err(|e| Error::ErrOthers(e.to_string()))?;
             }
         }
 
