@@ -4,6 +4,8 @@ mod extension_supported_elliptic_curves_test;
 use super::*;
 use crate::curve::named_curve::*;
 
+use anyhow::Result;
+
 const EXTENSION_SUPPORTED_GROUPS_HEADER_SIZE: usize = 6;
 
 // https://tools.ietf.org/html/rfc8422#section-5.1.1
@@ -21,7 +23,7 @@ impl ExtensionSupportedEllipticCurves {
         2 + 2 + self.elliptic_curves.len() * 2
     }
 
-    pub fn marshal<W: Write>(&self, writer: &mut W) -> Result<(), Error> {
+    pub fn marshal<W: Write>(&self, writer: &mut W) -> Result<()> {
         writer.write_u16::<BigEndian>(2 + 2 * self.elliptic_curves.len() as u16)?;
         writer.write_u16::<BigEndian>(2 * self.elliptic_curves.len() as u16)?;
         for v in &self.elliptic_curves {
@@ -31,7 +33,7 @@ impl ExtensionSupportedEllipticCurves {
         Ok(writer.flush()?)
     }
 
-    pub fn unmarshal<R: Read>(reader: &mut R) -> Result<Self, Error> {
+    pub fn unmarshal<R: Read>(reader: &mut R) -> Result<Self> {
         let _ = reader.read_u16::<BigEndian>()?;
 
         let group_count = reader.read_u16::<BigEndian>()? as usize / 2;
