@@ -9,7 +9,7 @@ use std::time::{Duration, SystemTime};
 use std::io::{BufReader, BufWriter};
 
 #[test]
-fn test_handshake_message() -> Result<(), Error> {
+fn test_handshake_message() -> Result<()> {
     let raw_handshake_message = vec![
         0x01, 0x00, 0x00, 0x29, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x29, 0xfe, 0xfd, 0xb6,
         0x2f, 0xce, 0x5c, 0x42, 0x54, 0xff, 0x86, 0xe1, 0x24, 0x41, 0x91, 0x42, 0x62, 0x15, 0xad,
